@@ -4,9 +4,9 @@ Main interface for resource-groups service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_resource_groups.type_defs import GroupIdentifierTypeDef
+    from mypy_boto3_resource_groups.type_defs import FailedResourceTypeDef
 
-    data: GroupIdentifierTypeDef = {...}
+    data: FailedResourceTypeDef = {...}
     ```
 """
 import sys
@@ -24,6 +24,10 @@ else:
 
 
 __all__ = (
+    "FailedResourceTypeDef",
+    "GroupConfigurationItemTypeDef",
+    "GroupConfigurationParameterTypeDef",
+    "GroupConfigurationTypeDef",
     "GroupIdentifierTypeDef",
     "GroupQueryTypeDef",
     "GroupTypeDef",
@@ -32,21 +36,71 @@ __all__ = (
     "ResourceQueryTypeDef",
     "CreateGroupOutputTypeDef",
     "DeleteGroupOutputTypeDef",
+    "GetGroupConfigurationOutputTypeDef",
     "GetGroupOutputTypeDef",
     "GetGroupQueryOutputTypeDef",
     "GetTagsOutputTypeDef",
     "GroupFilterTypeDef",
+    "GroupResourcesOutputTypeDef",
     "ListGroupResourcesOutputTypeDef",
     "ListGroupsOutputTypeDef",
     "PaginatorConfigTypeDef",
     "ResourceFilterTypeDef",
     "SearchResourcesOutputTypeDef",
     "TagOutputTypeDef",
+    "UngroupResourcesOutputTypeDef",
     "UntagOutputTypeDef",
     "UpdateGroupOutputTypeDef",
     "UpdateGroupQueryOutputTypeDef",
 )
 
+FailedResourceTypeDef = TypedDict(
+    "FailedResourceTypeDef",
+    {"ResourceArn": str, "ErrorMessage": str, "ErrorCode": str},
+    total=False,
+)
+
+_RequiredGroupConfigurationItemTypeDef = TypedDict(
+    "_RequiredGroupConfigurationItemTypeDef", {"Type": str}
+)
+_OptionalGroupConfigurationItemTypeDef = TypedDict(
+    "_OptionalGroupConfigurationItemTypeDef",
+    {"Parameters": List["GroupConfigurationParameterTypeDef"]},
+    total=False,
+)
+
+
+class GroupConfigurationItemTypeDef(
+    _RequiredGroupConfigurationItemTypeDef, _OptionalGroupConfigurationItemTypeDef
+):
+    pass
+
+
+_RequiredGroupConfigurationParameterTypeDef = TypedDict(
+    "_RequiredGroupConfigurationParameterTypeDef", {"Name": str}
+)
+_OptionalGroupConfigurationParameterTypeDef = TypedDict(
+    "_OptionalGroupConfigurationParameterTypeDef", {"Values": List[str]}, total=False
+)
+
+
+class GroupConfigurationParameterTypeDef(
+    _RequiredGroupConfigurationParameterTypeDef, _OptionalGroupConfigurationParameterTypeDef
+):
+    pass
+
+
+GroupConfigurationTypeDef = TypedDict(
+    "GroupConfigurationTypeDef",
+    {
+        "Configuration": List["GroupConfigurationItemTypeDef"],
+        "ProposedConfiguration": List["GroupConfigurationItemTypeDef"],
+        "Status": Literal["UPDATING", "UPDATE_COMPLETE", "UPDATE_FAILED"],
+        "FailureReason": str,
+    },
+    total=False,
+)
+
 GroupIdentifierTypeDef = TypedDict(
     "GroupIdentifierTypeDef", {"GroupName": str, "GroupArn": str}, total=False
 )
@@ -83,7 +137,12 @@ ResourceQueryTypeDef = TypedDict(
 
 CreateGroupOutputTypeDef = TypedDict(
     "CreateGroupOutputTypeDef",
-    {"Group": "GroupTypeDef", "ResourceQuery": "ResourceQueryTypeDef", "Tags": Dict[str, str]},
+    {
+        "Group": "GroupTypeDef",
+        "ResourceQuery": "ResourceQueryTypeDef",
+        "Tags": Dict[str, str],
+        "GroupConfiguration": "GroupConfigurationTypeDef",
+    },
     total=False,
 )
 
@@ -91,6 +150,12 @@ DeleteGroupOutputTypeDef = TypedDict(
     "DeleteGroupOutputTypeDef", {"Group": "GroupTypeDef"}, total=False
 )
 
+GetGroupConfigurationOutputTypeDef = TypedDict(
+    "GetGroupConfigurationOutputTypeDef",
+    {"GroupConfiguration": "GroupConfigurationTypeDef"},
+    total=False,
+)
+
 GetGroupOutputTypeDef = TypedDict("GetGroupOutputTypeDef", {"Group": "GroupTypeDef"}, total=False)
 
 GetGroupQueryOutputTypeDef = TypedDict(
@@ -102,7 +167,14 @@ GetTagsOutputTypeDef = TypedDict(
 )
 
 GroupFilterTypeDef = TypedDict(
-    "GroupFilterTypeDef", {"Name": Literal["resource-type"], "Values": List[str]}
+    "GroupFilterTypeDef",
+    {"Name": Literal["resource-type", "configuration-type"], "Values": List[str]},
+)
+
+GroupResourcesOutputTypeDef = TypedDict(
+    "GroupResourcesOutputTypeDef",
+    {"Succeeded": List[str], "Failed": List["FailedResourceTypeDef"]},
+    total=False,
 )
 
 ListGroupResourcesOutputTypeDef = TypedDict(
@@ -145,6 +217,12 @@ SearchResourcesOutputTypeDef = TypedDict(
 
 TagOutputTypeDef = TypedDict("TagOutputTypeDef", {"Arn": str, "Tags": Dict[str, str]}, total=False)
 
+UngroupResourcesOutputTypeDef = TypedDict(
+    "UngroupResourcesOutputTypeDef",
+    {"Succeeded": List[str], "Failed": List["FailedResourceTypeDef"]},
+    total=False,
+)
+
 UntagOutputTypeDef = TypedDict("UntagOutputTypeDef", {"Arn": str, "Keys": List[str]}, total=False)
 
 UpdateGroupOutputTypeDef = TypedDict(
